function im1 = AddGraywedge2Image(img,varargin)
%  function im1 = AddGraywedge2Image(img,varargin)
%  add gray wedge to image
%  inputs:
%     img: the image
%     fheight: (optional = 0.075) the height of gray wedge as faction of image dimension
%     range: (optional = [image_mn,image_max]) a length 2 vector of min and max gray values
%     position: (optional = 'r') position of bar, one of {'t','r','b','l'}, top, right, bottom, left
%  outputs:
%     im1: the image with bars
%  7/Jan/2013 10:08
% COPYRIGHT:  Robert E. Alvarez, 2013. All rights reserved.

nreqargs = 1;
if (nargin<nreqargs), error('number arguments %d is less than required %d',nargin,nreqargs); end;
fheight = 0.075;
rng = [min(img(:)) max(img(:))];
psns = 'trbl'; % possible positions
position = 'r';
  % process the optional arguments
if(nargin>nreqargs)
  i=1;
  while(i<=size(varargin,2))
     switch lower(varargin{i})
     case 'fheight';         fheight = varargin{i+1}; assert((fheight>0) && (fheight<=1));   i=i+1;
     case 'range';         rng = varargin{i+1}; assert(numel(rng)==2 ); i=i+1;
     case 'position';         position = lower(varargin{i+1}); assert(ismember(position,psns));   i=i+1;
    otherwise
      error('Unknown argument %s given',varargin{i});
     end
     i=i+1;
  end
end

  % rotate the image
rotang = 90*(strfind(psns,position)-1);
im1 = imrotate(img,rotang);
[ny,nx] = size(im1);
grayline = linspace(rng(1),rng(2),nx);
for ky = 1:round(fheight*ny)
    im1(ky,:) = grayline;
end
im1 = imrotate(im1,-rotang);
