% P45mudim3.m noise and dimensionality-3
%
% COPYRIGHT:  Aprend Technology and Robert E. ALvarez, 2014. All rights reserved.
 
%% init vars
post_title = 'P45mudim3';
% modify this for your computer
dirname = ['L:\Projects\Blog\Posts\' post_title '\'];
addpath([dirname 'code']);
% MakeBlogPostFileLists(post_title);

%% 
apy = ftp('ftp.aprendtech.com','bobalv','82FspqZ');

%% Prep data
   % x-ray spectrum
tube_voltage = 120; % kiloVolts  
[~,~,specdat] = XrayTubeSpectrumTasmip(tube_voltage,'number_spectrum','clipzeros');
     % clip even more zeros
specdat.specnum = specdat.specnum(10:end); % 10 was 'eyeballed' from data
specdat.egys = specdat.egys(10:end);
specdat.specnum_norm = specdat.specnum/trapz(specdat.egys,specdat.specnum);

material3 =  'adipose'; %'iodine'; % or   specify this before running script
tissues2 = {'soft_tissue','bone_cortical'}; % these are in every image
switch material3
     case 'adipose'
        tissues = [tissues2 'adipose'];
        specdat.mus = MusFromMaterials(tissues,specdat.egys);
        thicknesses = [1 .1 1]; % gm/cm^2 for tissues for this case
     case 'iodine'
        fracI = 0.01;
        tissues = [tissues2 'iodine'];
        muH2O = xraymu('H2O',specdat.egys);
        specdat.mus = [MusFromMaterials(tissues2,specdat.egys) ((1-fracI)*muH2O+fracI*xraymu('I',specdat.egys)) ];
        thicknesses = [1 .1 .1]; % gm/cm^2 for for tissues for this case
end
   % geometry: the box thicknesses are all set to one. 
   % For a specific case, multiply each column of ts_object by thickness
% init the simulated object -- define specs
nx = 256; ny = 256; % images width and height
zsiz = nx + 1i*ny; % dimensions of images
z1 = 1 + 1i;
   % boxes corners coords -- (image width)*(fractions of image width)
zcorners = nx*[ 
    .1*z1, .9*z1;
    .2*z1+0.4, 0.2*z1+0.4+ .2+.6i;
    .2*z1,.2*z1 + .2+.6i;
    ];
nmaterials = size(zcorners,1);  
tplanes = zeros(ny,nx,nmaterials); % one plane per material type
ts_object = zeros(nx*ny,nmaterials); % one row per pixel in image, columns are thicknesses of each type of material
for kmaterial = 1:nmaterials
    timg = Sim2D(zsiz,'rect',[zcorners(kmaterial,:),1]);
    tplanes(:,:,kmaterial) =  timg;
    ts_object(:,kmaterial) = timg(:);
end  
   % struct to save data  
geom.nx = nx;
geom.ny = ny;
geom.zcorners = zcorners;
geom.ts_object = ts_object;
geom.isobj = logical(ts_object);
geom.isair = ~any(geom.isobj,2);
geom.is_soft_only = geom.isobj(:,1) & (~any(geom.isobj(:,2:end),2));  

%% Compute the random image data
Nexponents = 3:7; 
Nphotons = 10.^(Nexponents); % number of photons incident per pixel, 
dat = MakeMudimImages(specdat,Nphotons,geom,thicknesses,'verbose');

%% make scatterplots of original and whitened data
kphot = 3; % nphotons case to use
zts2 = zcomp(dat.As2dim_with_noise(:,[(2*kphot):(2*kphot+1)] + 1));
Cts2 = cov(zcomp(zts2(geom.is_soft_only)));
[eigvecs,eigvals_matrix]=eig(Cts2); % eigenvectors and eigenvalues matrix
eigvals = diag(eigvals_matrix);
mwhiten = eigvecs*diag(1./sqrt(eigvals)); % whiten matrix uses sqrt of diagonal elements 
zswht = zcomp(zcomp(zts2)*mwhiten);
fh = figure;
linewid = 1.5;
kphot = kphot - 1; % zero based for easier indexing
set(fh,'color','w','position',[100 100 800 800])

subplot(221); % soft tissue regular As scatterplot
us = zts2(geom.is_soft_only);
plot(us(1:10:end),'.b')
axis square
title('As soft tissue','fontsize',13)
set(gca,'fontsize',12,'linewidth',linewid)

subplot(222) % scatterplots of air,bone,soft_tissue simultaneously
hold on
plot(us(1:10:end),'.b')
us = zts2(geom.isair);
plot(us(1:10:end),'.k')
us = zts2(geom.isobj(:,2));
plot(us(1:10:end),'.r')
hold off
axis([-1 1.5 -.02 .12])
title('As air,bone,soft_tissue','fontsize',13,'interpreter','none')
hl1 = legend('soft tissue','air','bone','location','northwest');
   % make the legend marker sizes larger
   % figured out the children numbers by trial and error
hs = get(hl1,'children');
mrksiz = 26;
for kh = [1 4 7]
    set(hs(kh),'markersize',mrksiz);
end
set(gca,'fontsize',12,'linewidth',linewid)

subplot(223) % soft tissue whitened
v = zswht(geom.is_soft_only);
plot(v(1:10:end),'.b')
axis square
title('As_whiten soft_tissue','fontsize',13,'interpreter','none')
set(gca,'fontsize',12,'linewidth',linewid)


subplot(224)  % different tissues in whitened coords
zmeans = zeros(3,1);
hold on
v = zswht(geom.is_soft_only);
zmeans(1) = mean(v);
plot(v(1:10:end),'.b')
v = zswht(geom.isair);
zmeans(2) = mean(v);
plot(v(1:10:end),'.k')
v = zswht(geom.isobj(:,2));
zmeans(3) = mean(v);
plot(v(1:10:end),'.r') % bone
axis([-400 50 -400 50])
axis square
  % plot the line from the air to the bone data
plot([zmeans(2),zmeans(3)],'-k','linewidth',linewid)
hold off
hl2 = legend('soft tissue','air','bone','location','southeast');
hs = get(hl2,'children');
for kh = [1 4 7]
    set(hs(kh),'markersize',mrksiz);
end
title('As_whiten air,bone,soft_tissue','fontsize',13,'interpreter','none')
set(gca,'fontsize',12,'linewidth',linewid)

%% export the figure as png and eps
figno = sprintf('-f%d',fh);
fname = 'whiten_plots';
   % export as eps
exportfig(fh,[dirname fname '.eps'],'width',6,'LockAxes',0,'color','cmyk');
    % export as png
set(fh,'papertype','usletter')
print(figno,'-dpng','-cmyk','-r100',[dirname fname '.png']) % resolution 100 dpi

%% display 2 basis funcs images vs. nphotons
fh = figure;
image_type = 'conv'; %'Avector'; %
switch image_type
    case 'Avector';
        img2disp =  dat.img2;
        labels = {'soft tissue','','bone'};
        fname = '2Dimages';
    case 'conv';
        img2disp =  dat.imgsconv; %
        labels =  {'Nphotons','','AspaceOptPjn'}; 
        fname = '2Dimages_conv'; 
end
imshow(img2disp',[-.5 1.5])
  % insert labels
do_numb
er_labels = true;
ht = zeros(numel(Nphotons),1);
  % offsets for labels on images
xoffset = 80 + 2*256;
yoffset = .3;
for k = 1:numel(Nphotons)
    if k==1
        koffset = 1;
        for ktissue = [1 3]
            x = 120+(koffset-1-.4)*ny;
            y = (k-.9)*ny;
            text(x,y,labels{ktissue},'fontsize',20,'color','k','interpreter','none','BackgroundColor','y');
            koffset = koffset + 1;
        end
    end
    if do_number_labels
        if (Nexponents(k) - floor(Nexponents(k))) < eps
            ht(k) = text(xoffset,(k-yoffset)*ny,['10^{' num2str(Nexponents(k)) '}'],'fontsize',24,'color','k','BackgroundColor','y');
        else
            ht(k) = text(xoffset,(k-yoffset)*ny,num2str(Nphotons(k)),'fontsize',24,'color','k','BackgroundColor','y');
        end    
    end    
end

%% export the figure as png and eps
figno = sprintf('-f%d',fh);
fname = 'ConvOptPjnImages';
   % export as eps
exportfig(fh,[dirname fname '.eps'],'width',6,'LockAxes',0,'color','cmyk');
    % export as png
set(fh,'papertype','usletter')
print(figno,'-dpng','-cmyk','-r100',[dirname fname '.png']) % resolution 100 dpi

