function [imnew,minmax] = imclip(img,f)
%  function  [imnew,minmax] = imclip(img,f)
%  Clip off a percentile of the data to lower dynamic range
%  inputs: 
%    img: original image
%    f: scalar or length 2 vector [fmin fmax] of fractions of range of image data or actual image values to clip. 
%       If scalar, fmin=f, fmax = 1-f;
%       e.g. [0.05 0.90] or 0.02
%  outputs:
%    imnew: the clipped image. same size as original
%    minmax: the min and max values is clipped image
%  example imc = imclip(img,[0.01 0.96]); outputs image imc same size as img but with data clipped at specified fractions
%  REA 4/21/06-5/24/13

assert(nargin==2);

nfs =  numel(f);
assert( nfs<=2);

if nfs==1
    fmin = f;
    fmax = 1-f;
else
     fmin = min(f);
     fmax = max(f);
end

 assert(fmin>=0);
 if fmin<eps
     fmin = eps;
 end
 
if range(f)>1.1 
          % it must be actual values
    %warning('assuming inputs %d and %d are image data values',fmin,fmax);
    minclip = fmin;
    maxclip = fmax;
else
    imgsort = sort(img(:));
    npix = numel(imgsort);
    
    minclip = imgsort(ceil(fmin*npix));
    maxclip = imgsort(fix(fmax*npix));
end


imnew = max(minclip,min(img,maxclip));
minmax = [minclip,maxclip]';