function imnew= imscale(img,f,varargin)
%  function imnew = imscale(img,f)
%  Clip off a percentile of the data to lower dynamic range, then scales image to [0 1] or specified range
%  inputs: 
%    img: original image
%    f: scalar or length 2 vector [fmin fmax] of fractions of range of image data or actual image values to clip. 
%       If scalar, fmin=f, fmax = 1-f;
%       e.g. [0.02 0.98] or 0.02
%    minmax: (optional = [0 1]) length 2 vector giving min and max of output image data range (will be sorted so order does not matter)
%  outputs:
%    imnew: the clipped, scaled image. same size as original
%  example imc = imclip(img,[0.01 0.96]); outputs image imc same size as img but with data clipped at specified fractions
%  REA 4/21/06-5/30/09

nreqargs = 2;

if(nargin<nreqargs), error('%d args required, only have %d',nreqargs,nargin);end

minmax = [0 1]; 
if(nargin>nreqargs)
  i=1;
  while(i<=size(varargin,2))
     switch lower(varargin{i})
     case 'minmax';          minmax = varargin{i+1}; assert(numel(minmax)==2); i=i+1;
    otherwise
      error('Unknown argument %s given',varargin{i});
     end
     i=i+1;
  end
end

rng_out = diff(sort(minmax));
if rng_out < eps
   error('output range cannot be zero');
end


[imnew,minmax_in] = imclip(img,f);

rng_in = diff(minmax_in);
if rng_in<2*eps
   warning('input range is small %g',rng_in);
   imnew = imnew + minmax(1);
else
    imnew = (imnew - minmax_in(1))*(rng_out/rng_in) + minmax(1);
end