function img = mkEllipse(zsiz, varargin)
% function img = mkEllipse(zsiz, varargin)
% Compute an image containing an ellipse of constant white_value 
%    inputs:
%      zsiz: a scalar giving the image dimensions, if complex,  nx+1i*ny else the side of a square zsiz = zsiz+1i*zsiz
%      zcenter: the ellipse center (optional: zsiz/2) a complex scalar (xcenter+1i*ycenter) 
%      zaxes: the ellipse semi-axes (optional = zsiz/4 ) if isreal, circle radius else (xaxis + 1i*yaxis) 
%      rotangle: (optional = 0), the rotation angle (degrees). 
%        This is wrt image coordinate system so may want to use 
%        negative angles to make rotation 'look right'
%      white_value: (optional =1) the contant value of the ellipse
%    outputs:
%      img: the output image of size (ny,nx) (rows,columns)  
% NOTE: the ellipse may be clipped off by the image rectangle coords
%  so use caution in specifying parameters
% example:img = mkellipse(256,'zaxes',64+32i,'rotangle',-20,'zcenter',32+45i,'white_value',-.25);
%   this gives clipped off ellipse wih negative values
% REA 5/4/09

nreqargs = 1;
assert(nargin>=nreqargs);
if isreal(zsiz)
   zsiz = zsiz + 1i*zsiz;
end   
  % process the optional arguments
zcenter = zsiz/2;
zaxes = zsiz/4;
rotangle = 0;
white_value = 1; 
if(nargin>nreqargs)
  i=1;
  while(i<=size(varargin,2))
     switch lower(varargin{i})
     case 'zcenter';         zcenter=varargin{i+1};  assert(isscalar(zcenter));   i=i+1;
     case 'zaxes';         zaxes=varargin{i+1};  if isreal(zaxes), zaxes=zaxes+1i*zaxes; end; assert(isscalar(zaxes));  i=i+1;
     case 'rotangle';         rotangle=varargin{i+1};  assert(isscalar(rotangle));   i=i+1;
     case 'white_value';         white_value=varargin{i+1};  assert(isscalar(white_value));   i=i+1;
    otherwise
      error('Unknown argument %s given',varargin{i});
     end
     i=i+1;
  end
end
nx = real(zsiz); ny = imag(zsiz);

  % See "Geometric Tools for Computer Graphics" by PJ Schneider and DH Eberly sec 5.5.2
C = [real(zcenter); imag(zcenter)];
rotangle = rotangle*pi/180; % convert to radians
R = [cos(rotangle) sin(rotangle); -sin(rotangle), cos(rotangle)];
D = diag(abs([real(zaxes),imag(zaxes)])); % make sure axes are non-negative
nangles = 2*max([nx ny]); % number of angles is more or less arbitrary, try this for now
zu = exp(1i*linspace(0,2*pi,nangles)); 
% zu = zu(abs(diff(zu))>eps); % get rid of dups
coords = repmat(C,1,numel(zu)) + R'*D*[real(zu); imag(zu)]; % a 2,npoints matrix
img = white_value*poly2mask(coords(1,:),coords(2,:),ny,nx);  